
# Slot: ~~edge label~~ _(deprecated)_




URI: [biolink:edge_label](https://w3id.org/biolink/vocab/edge_label)


## Domain and Range

[Association](Association.md) &#8594;  <sub>1..1</sub> [PredicateType](types/PredicateType.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Local names:** | | annotation predicate (ga4gh) |
|  | | predicate (translator) |
| **Mappings:** | | rdf:predicate |

